@@ -8,7 +8,6 @@ from transformers import (
     T5TokenizerFast as T5Tokenizer,
 )
 from torch.utils.data import Dataset, DataLoader
-from sklearn.model_selection import train_test_split
 import pytorch_lightning as pl
 from pytorch_lightning.loggers import WandbLogger
 from pytorch_lightning.callbacks.early_stopping import EarlyStopping
@@ -17,6 +16,7 @@ from pytorch_lightning import Trainer
 from getpass import getpass
 from huggingface_hub import HfApi, Repository
 from pathlib import Path
+from torchmetrics import Accuracy
 
 
 
@@ -167,6 +167,8 @@ class LightningModel(pl.LightningModule):
         self.model = model
         self.tokenizer = tokenizer
         self.output = output
+        self.val_acc = Accuracy()
+        self.train_acc = Accuracy()
 
     def forward(self, input_ids, attention_mask, decoder_attention_mask, labels=None):
         """ forward step """
@@ -192,8 +194,9 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-
+        train_acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("train_loss", loss, prog_bar=True, logger=True)
+        self.log(f"train_acc", train_acc, prog_bar=True,logger=True)
         return loss
 
     def validation_step(self, batch, batch_size):
@@ -209,9 +212,9 @@ class LightningModel(pl.LightningModule):
             decoder_attention_mask=labels_attention_mask,
             labels=labels,
         )
-        acc = self.val_acc(outputs.logits.argmax(1), labels)
+        val_acc = self.val_acc(outputs.logits.argmax(1), labels)
         self.log("val_loss", loss, prog_bar=True, logger=True)
-        self.log(f"val_acc", acc, prog_bar=True,logger=True)
+        self.log(f"val_acc", val_acc, prog_bar=True,logger=True)
         return loss
 
     def test_step(self, batch, batch_size):
